@@ -1,37 +1,37 @@
-class CredentialShieldException(RuntimeError):
+class JwtValidatorException(RuntimeError):
     pass
 
 
-class InvalidTokenFormatException(CredentialShieldException):
+class InvalidTokenFormatException(JwtValidatorException):
     def __init__(self) -> None:
         super().__init__('Token format is incorrect')
 
 
-class InvalidApplicationIdException(CredentialShieldException):
+class InvalidApplicationIdException(JwtValidatorException):
     def __init__(self) -> None:
         super().__init__('Invalid application id')
 
 
-class InvalidTokenSourceException(CredentialShieldException):
+class InvalidTokenSourceException(JwtValidatorException):
     def __init__(self) -> None:
         super().__init__('Token issuer is not trusted')
 
 
-class InvalidAccessTokenException(CredentialShieldException):
+class InvalidAccessTokenException(JwtValidatorException):
     def __init__(self) -> None:
         super().__init__('Invalid access token')
 
 
-class ExpiredTokenException(CredentialShieldException):
+class ExpiredTokenException(JwtValidatorException):
     def __init__(self) -> None:
         super().__init__('Token has expired')
 
 
-class ScopeNotAllowedException(CredentialShieldException):
+class ScopeNotAllowedException(JwtValidatorException):
     def __init__(self) -> None:
         super().__init__('Token is not valid in this scope')
 
 
-class InvalidPublicKeyError(CredentialShieldException):
+class InvalidPublicKeyError(JwtValidatorException):
     def __init__(self) -> None:
         super().__init__('Invalid public key')
